@@ -44,7 +44,6 @@
 #include "egg-string.h"
 #include "egg-dbus-monitor.h"
 
-#include "gpk-consolekit.h"
 #include "gpk-common.h"
 #include "gpk-gnome.h"
 #include "gpk-auto-refresh.h"
@@ -226,17 +225,17 @@ gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
 		NULL};
 	const char *license[] = {
 		N_("Licensed under the GNU General Public License Version 2"),
-		N_("PackageKit is free software; you can redistribute it and/or\n"
-		   "modify it under the terms of the GNU General Public License\n"
-		   "as published by the Free Software Foundation; either version 2\n"
+		N_("PackageKit is free software; you can redistribute it and/or "
+		   "modify it under the terms of the GNU General Public License "
+		   "as published by the Free Software Foundation; either version 2 "
 		   "of the License, or (at your option) any later version."),
-		N_("PackageKit is distributed in the hope that it will be useful,\n"
-		   "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+		N_("PackageKit is distributed in the hope that it will be useful, "
+		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
 		   "GNU General Public License for more details."),
-		N_("You should have received a copy of the GNU General Public License\n"
-		   "along with this program; if not, write to the Free Software\n"
-		   "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA\n"
+		N_("You should have received a copy of the GNU General Public License "
+		   "along with this program; if not, write to the Free Software "
+		   "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA "
 		   "02110-1301, USA.")
 	};
 	const char *translators = _("translator-credits");
@@ -257,6 +256,7 @@ gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
 			       "version", VERSION,
 			       "copyright", "Copyright \xc2\xa9 2007-2009 Richard Hughes",
 			       "license", license_trans,
+			       "wrap-license", TRUE,
 				/* TRANSLATORS: website label */
 			       "website-label", _("PackageKit Website"),
 			       "website", "www.packagekit.org",
@@ -370,45 +370,17 @@ out:
 	return ret;
 }
 
-/**
- * gpk_check_update_menuitem_show_updates_cb:
- **/
-static void
-gpk_check_update_menuitem_show_updates_cb (GtkMenuItem *item, gpointer data)
-{
-	const gchar *command = "gpk-update-viewer";
-	if (!g_spawn_command_line_async (command, NULL))
-		egg_warning ("Couldn't execute command: %s", command);
-}
-
 /**
  * gpk_check_update_activate_update_cb:
- * @button: Which buttons are pressed
  *
- * Callback when the icon is clicked
+ * Callback when the icon is left clicked
  **/
 static void
 gpk_check_update_activate_update_cb (GtkStatusIcon *status_icon, GpkCheckUpdate *icon)
 {
-	GtkMenu *menu = (GtkMenu*) gtk_menu_new ();
-	GtkWidget *item;
-	GtkWidget *image;
-
-	egg_debug ("icon left clicked");
-
-	/* TRANSLATORS: context menu to execute the update viewer  */
-	item = gtk_image_menu_item_new_with_mnemonic (_("_Show Updates"));
-	image = gtk_image_new_from_icon_name (GPK_ICON_SOFTWARE_UPDATE, GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
-	g_signal_connect (G_OBJECT (item), "activate",
-			  G_CALLBACK (gpk_check_update_menuitem_show_updates_cb), icon);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-	/* show the menu */
-	gtk_widget_show_all (GTK_WIDGET (menu));
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-			gtk_status_icon_position_menu, status_icon,
-			1, gtk_get_current_event_time());
+	const gchar *command = "gpk-update-viewer";
+	if (!g_spawn_command_line_async (command, NULL))
+		egg_warning ("Couldn't execute command: %s", command);
 }
 
 /**
@@ -558,7 +530,7 @@ gpk_check_update_critical_updates_warning (GpkCheckUpdate *cupdate, const gchar
 
 	/* do the bubble */
 	egg_debug ("title=%s, message=%s", title, message);
-	notification = notify_notification_new (title, message, "help-browser", NULL);
+	notification = notify_notification_new_with_status_icon (title, message, "help-browser", cupdate->priv->status_icon);
 	if (notification == NULL) {
 		egg_warning ("failed to get bubble");
 		return;
@@ -687,7 +659,9 @@ gpk_check_update_check_on_battery (GpkCheckUpdate *cupdate)
 	/* TRANSLATORS: policy says update, but we are on battery and so prompt */
 	message = _("Automatic updates are not being installed as the computer is running on battery power");
 	/* TRANSLATORS: informs user will not install by default */
-	notification = notify_notification_new (_("Updates not installed"), message, "help-browser", NULL);
+	notification = notify_notification_new_with_status_icon (_("Updates not installed"),
+								 message, "help-browser",
+								 cupdate->priv->status_icon);
 	notify_notification_set_timeout (notification, 15000);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 //	notify_notification_add_action (notification, "do-not-show-update-not-battery",
@@ -777,10 +751,10 @@ gpk_check_update_notify_doing_updates (GpkCheckUpdate *cupdate)
 		goto out;
 
 	/* TRANSLATORS: title: notification when we scheduled an automatic update */
-	notification = notify_notification_new (_("Updates are being installed"),
+	notification = notify_notification_new_with_status_icon (_("Updates are being installed"),
 						/* TRANSLATORS: tell the user why the hard disk is grinding... */
 						_("Updates are being automatically installed on your computer"),
-						"software-update-urgent", NULL);
+						"software-update-urgent", cupdate->priv->status_icon);
 	notify_notification_set_timeout (notification, 15000);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 	/* TRANSLATORS: button: cancel the update system */
@@ -937,7 +911,9 @@ gpk_check_update_process_updates (GpkCheckUpdate *cupdate, PkPackageList *list,
 
 	/* are we on battery and configured to skip the action */
 	ret = gpk_check_update_check_on_battery (cupdate);
-	if (!ret) {
+	if (!ret &&
+	    ((update == GPK_UPDATE_ENUM_SECURITY && security_array->len > 0) ||
+	      update == GPK_UPDATE_ENUM_ALL)) {
 		egg_debug ("on battery so not doing update");
 
 		/* play the sound, using sounds from the naming spec */
@@ -1199,7 +1175,7 @@ gpk_check_update_process_distro_upgrades (GpkCheckUpdate *cupdate, PkObjList *ar
 
 	/* TRANSLATORS: a distro update is available, e.g. Fedora 8 to Fedora 9 */
 	title = _("Distribution upgrades available");
-	notification = notify_notification_new (title, string->str, "help-browser", NULL);
+	notification = notify_notification_new_with_status_icon (title, string->str, "help-browser", cupdate->priv->status_icon);
 	if (notification == NULL) {
 		egg_warning ("failed to get bubble");
 		return;
@@ -1437,7 +1413,9 @@ gpk_check_update_finished_notify (GpkCheckUpdate *cupdate, PkClient *client)
 	}
 
 	/* TRANSLATORS: title: system update completed all okay */
-	notification = notify_notification_new (_("The system update has completed"), message_text->str, "help-browser", NULL);
+	notification = notify_notification_new_with_status_icon (_("The system update has completed"),
+								 message_text->str, "help-browser",
+								 cupdate->priv->status_icon);
 	notify_notification_set_timeout (notification, 15000);
 	notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
 	if (restart == PK_RESTART_ENUM_SYSTEM) {
