@@ -52,6 +52,7 @@ static const PkEnumMatch enum_info_icon_name[] = {
 	{PK_INFO_ENUM_COLLECTION_INSTALLED,	"pk-collection-installed"},
 	{PK_INFO_ENUM_COLLECTION_AVAILABLE,	"pk-collection-available"},
 	{PK_INFO_ENUM_FINISHED,			"dialog-information"},
+	{PK_INFO_ENUM_REINSTALLING,		"dialog-information"},
 	{0, NULL}
 };
 
@@ -71,6 +72,7 @@ static const PkEnumMatch enum_status_icon_name[] = {
 	{PK_STATUS_ENUM_FINISHED,		"pk-package-cleanup"}, /* TODO: need better icon */
 	{PK_STATUS_ENUM_GENERATE_PACKAGE_LIST,	"pk-refresh-cache"}, /* TODO: need better icon */
 	{PK_STATUS_ENUM_WAITING_FOR_LOCK,	"pk-package-blocked"},
+	{PK_STATUS_ENUM_WAITING_FOR_AUTH,	"gtk-dialog-authentication"},
 	{PK_STATUS_ENUM_INFO,			"pk-package-info"},
 	{PK_STATUS_ENUM_INSTALL,		"pk-package-add"},
 	{PK_STATUS_ENUM_LOADING_CACHE,		"pk-refresh-cache"},
@@ -88,6 +90,9 @@ static const PkEnumMatch enum_status_icon_name[] = {
 	{PK_STATUS_ENUM_TEST_COMMIT,		"pk-package-info"}, /* TODO: need better icon */
 	{PK_STATUS_ENUM_UPDATE,			"pk-package-update"},
 	{PK_STATUS_ENUM_WAIT,			"pk-wait"},
+	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"pk-package-info"},
+	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"pk-package-info"},
+	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"pk-package-info"},
 	{0, NULL}
 };
 
@@ -107,6 +112,7 @@ static const PkEnumMatch enum_status_animation[] = {
 	{PK_STATUS_ENUM_FINISHED,		"pk-package-cleanup"},
 	{PK_STATUS_ENUM_GENERATE_PACKAGE_LIST,	"pk-action-searching"},
 	{PK_STATUS_ENUM_WAITING_FOR_LOCK,	"pk-action-waiting"},
+	{PK_STATUS_ENUM_WAITING_FOR_AUTH,	"pk-action-waiting"},
 	{PK_STATUS_ENUM_INFO,			"process-working"},
 	{PK_STATUS_ENUM_INSTALL,		"pk-action-installing"},
 	{PK_STATUS_ENUM_LOADING_CACHE,		"pk-action-refresh-cache"},
@@ -124,6 +130,9 @@ static const PkEnumMatch enum_status_animation[] = {
 	{PK_STATUS_ENUM_TEST_COMMIT,		"pk-action-testing"},
 	{PK_STATUS_ENUM_UPDATE,			"pk-action-installing"},
 	{PK_STATUS_ENUM_WAIT,			"pk-action-waiting"},
+	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"pk-package-info"},
+	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"pk-package-info"},
+	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"pk-package-info"},
 	{0, NULL}
 };
 
@@ -159,6 +168,10 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_UPDATE_PACKAGES,		"pk-package-update"},
 	{PK_ROLE_ENUM_UPDATE_SYSTEM,		"system-software-update"},
 	{PK_ROLE_ENUM_WHAT_PROVIDES,		"pk-package-search"},
+	{PK_ROLE_ENUM_SIMULATE_INSTALL_FILES,	"pk-package-add"},
+	{PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES, "pk-package-add"},
+	{PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,	"pk-package-delete"},
+	{PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,	"pk-package-update"},
 	{0, NULL}
 };
 
@@ -207,6 +220,8 @@ static const PkEnumMatch enum_restart_icon_name[] = {
 	{PK_RESTART_ENUM_SYSTEM,		"system-shutdown"},
 	{PK_RESTART_ENUM_SESSION,		"system-log-out"},
 	{PK_RESTART_ENUM_APPLICATION,		"emblem-symbolic-link"},
+	{PK_RESTART_ENUM_SECURITY_SYSTEM,	"system-shutdown"},
+	{PK_RESTART_ENUM_SECURITY_SESSION,	"system-log-out"},
 	{0, NULL}
 };
 
@@ -216,6 +231,8 @@ static const PkEnumMatch enum_restart_dialog_icon_name[] = {
 	{PK_RESTART_ENUM_SYSTEM,		"dialog-error"},
 	{PK_RESTART_ENUM_SESSION,		"dialog-warning"},
 	{PK_RESTART_ENUM_APPLICATION,		"dialog-warning"},
+	{PK_RESTART_ENUM_SECURITY_SYSTEM,	"dialog-error"},
+	{PK_RESTART_ENUM_SECURITY_SESSION,	"dialog-error"},
 	{0, NULL}
 };
 
@@ -233,15 +250,7 @@ static const PkEnumMatch enum_message_icon_name[] = {
 	{PK_MESSAGE_ENUM_COULD_NOT_FIND_PACKAGE,"dialog-error"},
 	{PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,	"dialog-information"},
 	{PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED,	"dialog-information"},
-	{0, NULL}
-};
-
-static const PkEnumMatch enum_freq[] = {
-	{GPK_FREQ_ENUM_UNKNOWN,			"unknown"},	/* fall though value */
-	{GPK_FREQ_ENUM_HOURLY,			"hourly"},
-	{GPK_FREQ_ENUM_DAILY,			"daily"},
-	{GPK_FREQ_ENUM_WEEKLY,			"weekly"},
-	{GPK_FREQ_ENUM_NEVER,			"never"},
+	{PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED,	"dialog-information"},
 	{0, NULL}
 };
 
@@ -253,34 +262,6 @@ static const PkEnumMatch enum_update[] = {
 	{0, NULL}
 };
 
-/**
- * gpk_freq_enum_from_text:
- * @freq: Text describing the enumerated type
- *
- * Converts a text enumerated type to its unsigned integer representation
- *
- * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
- **/
-GpkFreqEnum
-gpk_freq_enum_from_text (const gchar *freq)
-{
-	return pk_enum_find_value (enum_freq, freq);
-}
-
-/**
- * gpk_freq_enum_to_text:
- * @freq: The enumerated type value
- *
- * Converts a enumerated type to its text representation
- *
- * Return value: the enumerated constant value, e.g. "available"
- **/
-const gchar *
-gpk_freq_enum_to_text (GpkFreqEnum freq)
-{
-	return pk_enum_find_string (enum_freq, freq);
-}
-
 /**
  * gpk_update_enum_from_text:
  * @update: Text describing the enumerated type
@@ -491,6 +472,39 @@ gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
 	case PK_ERROR_ENUM_NOT_AUTHORIZED:
 		text = _("Authorization failed");
 		break;
+	case PK_ERROR_ENUM_UPDATE_NOT_FOUND:
+		text = _("Update not found");
+		break;
+	case PK_ERROR_ENUM_CANNOT_INSTALL_REPO_UNSIGNED:
+		text = _("Cannot install from untrusted source");
+		break;
+	case PK_ERROR_ENUM_CANNOT_UPDATE_REPO_UNSIGNED:
+		text = _("Cannot update from untrusted source");
+		break;
+	case PK_ERROR_ENUM_CANNOT_GET_FILELIST:
+		text = _("Cannot get the file list");
+		break;
+	case PK_ERROR_ENUM_CANNOT_GET_REQUIRES:
+		text = _("Cannot get package requires");
+		break;
+	case PK_ERROR_ENUM_CANNOT_DISABLE_REPOSITORY:
+		text = _("Cannot disable source");
+		break;
+	case PK_ERROR_ENUM_RESTRICTED_DOWNLOAD:
+		text = _("The download failed");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_CONFIGURE:
+		text = _("Package failed to configure");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_BUILD:
+		text = _("Package failed to build");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_INSTALL:
+		text = _("Package failed to install");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE:
+		text = _("Package failed to be removed");
+		break;
 	default:
 		egg_warning ("Unknown error");
 	}
@@ -507,7 +521,7 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 	switch (code) {
 	case PK_ERROR_ENUM_NO_NETWORK:
 		text = _("There is no network connection available.\n"
-			 "Please check your connection settings and try again");
+			 "Please check your connection settings and try again.");
 		break;
 	case PK_ERROR_ENUM_NO_CACHE:
 		text = _("The package list needs to be rebuilt.\n"
@@ -571,7 +585,7 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 		break;
 	case PK_ERROR_ENUM_REPO_NOT_FOUND:
 		text = _("The remote software source name was not found.\n"
-			 "You may need to enable an item in Software Sources");
+			 "You may need to enable an item in Software Sources.");
 		break;
 	case PK_ERROR_ENUM_CANNOT_REMOVE_SYSTEM_PACKAGE:
 		text = _("Removing a protected system package is not allowed.");
@@ -607,7 +621,7 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 			 "This is usually due to mixing packages from different software sources.");
 		break;
 	case PK_ERROR_ENUM_REPO_NOT_AVAILABLE:
-		text = _("There was a (possibly temporary) problem connecting to a software source\n"
+		text = _("There was a (possibly temporary) problem connecting to a software source.\n"
 			 "Please check the detailed error for further details.");
 		break;
 	case PK_ERROR_ENUM_FAILED_INITIALIZATION:
@@ -678,7 +692,47 @@ gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
 		text = _("Additional media is required to complete the transaction.");
 		break;
 	case PK_ERROR_ENUM_NOT_AUTHORIZED:
-		text = _("You have failed to provide correct authentication. Please check any passwords or account settings.");
+		text = _("You have failed to provide correct authentication.\n"
+			 "Please check any passwords or account settings.");
+		break;
+	case PK_ERROR_ENUM_UPDATE_NOT_FOUND:
+		text = _("The specified update could not be found.\n"
+			 "It could have already been installed or no longer available on the remote server.");
+		break;
+	case PK_ERROR_ENUM_CANNOT_INSTALL_REPO_UNSIGNED:
+		text = _("The package could not be installed from untrusted source.");
+		break;
+	case PK_ERROR_ENUM_CANNOT_UPDATE_REPO_UNSIGNED:
+		text = _("The package could not be updated from untrusted source.");
+		break;
+	case PK_ERROR_ENUM_CANNOT_GET_FILELIST:
+		text = _("The file list is not available for this package.");
+		break;
+	case PK_ERROR_ENUM_CANNOT_GET_REQUIRES:
+		text = _("The information about what requires this package could not be obtained.");
+		break;
+	case PK_ERROR_ENUM_CANNOT_DISABLE_REPOSITORY:
+		text = _("The specified software source could not be disabled.");
+		break;
+	case PK_ERROR_ENUM_RESTRICTED_DOWNLOAD:
+		text = _("The download could not be done automatically and should be done manually.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_CONFIGURE:
+		text = _("One of the selected packages failed to configure correctly.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_BUILD:
+		text = _("One of the selected packages failed to build correctly.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_INSTALL:
+		text = _("One of the selected packages failed to install correctly.\n"
+			 "More information is available in the detailed report.");
+		break;
+	case PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE:
+		text = _("One of the selected packages failed to be removed correctly.\n"
+			 "More information is available in the detailed report.");
 		break;
 	default:
 		egg_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
@@ -696,16 +750,22 @@ gpk_restart_enum_to_localised_text_future (PkRestartEnum restart)
 	const gchar *text = NULL;
 	switch (restart) {
 	case PK_RESTART_ENUM_NONE:
-		text = _("No restart is necessary");
+		text = _("No restart is necessary.");
 		break;
 	case PK_RESTART_ENUM_APPLICATION:
-		text = _("You will be required to restart this application");
+		text = _("You will be required to restart this application.");
 		break;
 	case PK_RESTART_ENUM_SESSION:
-		text = _("You will be required to log out and back in");
+		text = _("You will be required to log out and back in.");
 		break;
 	case PK_RESTART_ENUM_SYSTEM:
-		text = _("A restart will be required");
+		text = _("A restart will be required.");
+		break;
+	case PK_RESTART_ENUM_SECURITY_SESSION:
+		text = _("You will be required to log out and back in due to a security update.");
+		break;
+	case PK_RESTART_ENUM_SECURITY_SYSTEM:
+		text = _("A restart will be required due to a security update.");
 		break;
 	default:
 		egg_warning ("restart unrecognised: %i", restart);
@@ -722,16 +782,22 @@ gpk_restart_enum_to_localised_text (PkRestartEnum restart)
 	const gchar *text = NULL;
 	switch (restart) {
 	case PK_RESTART_ENUM_NONE:
-		text = _("No restart is required");
+		text = _("No restart is required.");
 		break;
 	case PK_RESTART_ENUM_SYSTEM:
-		text = _("A restart is required");
+		text = _("A restart is required.");
 		break;
 	case PK_RESTART_ENUM_SESSION:
-		text = _("You need to log out and log back in");
+		text = _("You need to log out and log back in.");
 		break;
 	case PK_RESTART_ENUM_APPLICATION:
-		text = _("You need to restart the application");
+		text = _("You need to restart the application.");
+		break;
+	case PK_RESTART_ENUM_SECURITY_SESSION:
+		text = _("You need to log out and log back in to remain secure.");
+		break;
+	case PK_RESTART_ENUM_SECURITY_SYSTEM:
+		text = _("A restart is required to remain secure.");
 		break;
 	default:
 		egg_warning ("restart unrecognised: %i", restart);
@@ -809,7 +875,9 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 	case PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED:
 		text = _("Package is already installed");
 		break;
-
+	case PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED:
+		text = _("Automatic cleanup is being ignored");
+		break;
 	default:
 		egg_warning ("message unrecognised: %i", message);
 	}
@@ -952,6 +1020,22 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 		/* TRANSLATORS: The transaction state */
 		text = _("Waiting for package manager lock");
 		break;
+	case PK_STATUS_ENUM_WAITING_FOR_AUTH:
+		/* TRANSLATORS: waiting for user to type in a password */
+		text = _("Waiting for authentication");
+		break;
+	case PK_STATUS_ENUM_SCAN_PROCESS_LIST:
+		/* TRANSLATORS: we are updating the list of processes */
+		text = _("Updating the list of running applications");
+		break;
+	case PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES:
+		/* TRANSLATORS: we are checking executable files in use */
+		text = _("Checking for applications currently in use");
+		break;
+	case PK_STATUS_ENUM_CHECK_LIBRARIES:
+		/* TRANSLATORS: we are checking for libraries in use */
+		text = _("Checking for libraries currently in use");
+		break;
 	default:
 		egg_warning ("status unrecognised: %s", pk_status_enum_to_text (status));
 	}
@@ -1084,6 +1168,10 @@ gpk_info_enum_to_localised_present (PkInfoEnum info)
 		/* TRANSLATORS: The action of the package, in present tense */
 		text = _("Obsoleting");
 		break;
+	case PK_INFO_ENUM_REINSTALLING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = _("Reinstalling");
+		break;
 	default:
 		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
@@ -1122,6 +1210,10 @@ gpk_info_enum_to_localised_past (PkInfoEnum info)
 		/* TRANSLATORS: The action of the package, in past tense */
 		text = _("Obsoleted");
 		break;
+	case PK_INFO_ENUM_REINSTALLING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = _("Reinstalled");
+		break;
 	default:
 		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
@@ -1260,6 +1352,22 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Getting old transactions");
 		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Simulating the install");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Simulating the install of files");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Simulating the remove");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in present tense */
+		text = _("Simulating the update");
+		break;
 	default:
 		egg_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
 	}
@@ -1400,6 +1508,22 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Got old transactions");
 		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Simulated the install");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Simulated the install of files");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Simulated the remove");
+		break;
+	case PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES:
+		/* TRANSLATORS: The role of the transaction, in past tense */
+		text = _("Simulated the update");
+		break;
 	default:
 		egg_warning ("role unrecognised: %s", pk_role_enum_to_text (role));
 	}
@@ -1708,7 +1832,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the role icon name enums");
 	for (i=0; i<PK_ROLE_ENUM_UNKNOWN; i++) {
 		string = gpk_role_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_role_enum_to_text (i));
 			break;
 		}
@@ -1719,7 +1843,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the status animation enums");
 	for (i=0; i<PK_ROLE_ENUM_UNKNOWN; i++) {
 		string = gpk_status_enum_to_animation (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_role_enum_to_text (i));
 			break;
 		}
@@ -1730,7 +1854,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the info icon names enums");
 	for (i=0; i<PK_INFO_ENUM_UNKNOWN; i++) {
 		string = gpk_info_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_info_enum_to_text (i));
 			break;
 		}
@@ -1752,7 +1876,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the status icon names enums");
 	for (i=0; i<PK_STATUS_ENUM_UNKNOWN; i++) {
 		string = gpk_status_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_status_enum_to_text (i));
 			break;
 		}
@@ -1763,7 +1887,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the restart icon names enums");
 	for (i=0; i<PK_RESTART_ENUM_UNKNOWN; i++) {
 		string = gpk_restart_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_restart_enum_to_text (i));
 			break;
 		}
@@ -1807,7 +1931,7 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the message icon name enums");
 	for (i=0; i<PK_MESSAGE_ENUM_UNKNOWN; i++) {
 		string = gpk_message_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_message_enum_to_text (i));
 			break;
 		}
@@ -1851,25 +1975,13 @@ gpk_enum_test (gpointer data)
 	egg_test_title (test, "check we convert all the group icon name enums");
 	for (i=0; i<PK_GROUP_ENUM_UNKNOWN; i++) {
 		string = gpk_group_enum_to_icon_name (i);
-		if (string == NULL || egg_strequal (string, "help-browser")) {
+		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
 			egg_test_failed (test, "failed to get %s", pk_group_enum_to_text (i));
 			break;
 		}
 	}
 	egg_test_success (test, NULL);
 
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the freq bitfield");
-	for (i=0; i<=GPK_FREQ_ENUM_UNKNOWN; i++) {
-		string = gpk_freq_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
 	/************************************************************/
 	egg_test_title (test, "check we convert all the update bitfield");
 	for (i=0; i<=GPK_UPDATE_ENUM_UNKNOWN; i++) {
