@@ -214,6 +214,7 @@ gpk_helper_run_add_desktop_file (GpkHelperRun *helper, const gchar *package_id,
 	GKeyFile *file;
 	PkPackageId *id;
 	gint weight;
+	gboolean hidden;
 
 	/* get weight */
 	weight = gpk_desktop_get_file_weight (filename);
@@ -231,7 +232,22 @@ gpk_helper_run_add_desktop_file (GpkHelperRun *helper, const gchar *package_id,
 	}
 
 	/* get exec */
-	exec = g_key_file_get_string (file, G_KEY_FILE_DESKTOP_GROUP, "TryExec", NULL);
+	hidden = g_key_file_get_boolean (file, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_HIDDEN, NULL);
+	if (hidden) {
+		egg_debug ("hidden, so ignoring %s", filename);
+		ret = FALSE;
+		goto out;
+	}
+
+	/* is WM? */
+	ret = !g_key_file_has_group (file, "Window Manager");
+	if (!ret) {
+		egg_debug ("ignoring Window Manager");
+		goto out;
+	}
+
+	/* get exec */
+	exec = g_key_file_get_string (file, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_TRY_EXEC, NULL);
 	if (exec == NULL)
 		exec = g_key_file_get_string (file, G_KEY_FILE_DESKTOP_GROUP, "Exec", NULL);
 
@@ -242,20 +258,20 @@ gpk_helper_run_add_desktop_file (GpkHelperRun *helper, const gchar *package_id,
 	}
 
 	/* get name */
-	text = g_key_file_get_locale_string (file, G_KEY_FILE_DESKTOP_GROUP, "Name", NULL, NULL);
+	text = g_key_file_get_locale_string (file, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_NAME, NULL, NULL);
 	if (text != NULL)
 		name = g_markup_escape_text (text, -1);
 	g_free (text);
 
 	/* get icon */
-	icon = g_key_file_get_string (file, G_KEY_FILE_DESKTOP_GROUP, "Icon", NULL);
+	icon = g_key_file_get_string (file, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_ICON, NULL);
 	if (icon == NULL || !gpk_desktop_check_icon_valid (icon)) {
 		g_free (icon);
 		icon = g_strdup (gpk_info_enum_to_icon_name (PK_INFO_ENUM_AVAILABLE));
 	}
 
 	/* get summary */
-	text = g_key_file_get_locale_string (file, G_KEY_FILE_DESKTOP_GROUP, "Comment", NULL, NULL);
+	text = g_key_file_get_locale_string (file, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_COMMENT, NULL, NULL);
 	if (text == NULL)
 		text = g_key_file_get_locale_string (file, G_KEY_FILE_DESKTOP_GROUP, "GenericName", NULL, NULL);
 	if (text != NULL)
@@ -360,6 +376,8 @@ gpk_helper_run_show (GpkHelperRun *helper, gchar **package_ids)
 
 	/* clear old list */
 	gtk_list_store_clear (helper->priv->list_store);
+	g_free (helper->priv->full_path);
+	helper->priv->full_path = NULL;
 
 	/* add all the apps */
 	len = gpk_helper_run_add_package_ids (helper, package_ids);
@@ -391,8 +409,8 @@ gpk_helper_run_set_parent (GpkHelperRun *helper, GtkWindow *window)
 	gtk_window_set_transient_for (widget, window);
 	gtk_window_set_modal (widget, TRUE);
 
-	/* this is a modal popup, so don't show a window title */
-	gtk_window_set_title (widget, "");
+	/* this is a modal popup */
+	gtk_window_set_type_hint (widget, GDK_WINDOW_TYPE_HINT_DIALOG);
 
 	return TRUE;
 }
