@@ -41,6 +41,7 @@
 
 #include "egg-debug.h"
 #include "egg-string.h"
+#include "egg-console-kit.h"
 
 #include "gpk-common.h"
 #include "gpk-session.h"
@@ -48,7 +49,6 @@
 #include "gpk-watch.h"
 #include "gpk-modal-dialog.h"
 #include "gpk-inhibit.h"
-#include "gpk-consolekit.h"
 #include "gpk-enum.h"
 
 static void     gpk_watch_finalize	(GObject       *object);
@@ -76,6 +76,7 @@ struct GpkWatchPrivate
 	guint			 set_proxy_timeout;
 	gchar			*error_details;
 	gboolean		 hide_warning;
+	EggConsoleKit		*console;
 };
 
 typedef struct {
@@ -764,17 +765,17 @@ gpk_watch_show_about_cb (GtkMenuItem *item, gpointer data)
 		NULL};
 	const char *license[] = {
 		N_("Licensed under the GNU General Public License Version 2"),
-		N_("PackageKit is free software; you can redistribute it and/or\n"
-		   "modify it under the terms of the GNU General Public License\n"
-		   "as published by the Free Software Foundation; either version 2\n"
+		N_("PackageKit is free software; you can redistribute it and/or "
+		   "modify it under the terms of the GNU General Public License "
+		   "as published by the Free Software Foundation; either version 2 "
 		   "of the License, or (at your option) any later version."),
-		N_("PackageKit is distributed in the hope that it will be useful,\n"
-		   "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+		N_("PackageKit is distributed in the hope that it will be useful, "
+		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
 		   "GNU General Public License for more details."),
-		N_("You should have received a copy of the GNU General Public License\n"
-		   "along with this program; if not, write to the Free Software\n"
-		   "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA\n"
+		N_("You should have received a copy of the GNU General Public License "
+		   "along with this program; if not, write to the Free Software "
+		   "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA "
 		   "02110-1301, USA.")
 	};
 	const char *translators = _("translator-credits");
@@ -795,6 +796,7 @@ gpk_watch_show_about_cb (GtkMenuItem *item, gpointer data)
 			       "version", VERSION,
 			       "copyright", "Copyright \xc2\xa9 2007-2009 Richard Hughes",
 			       "license", license_trans,
+			       "wrap-license", TRUE,	
 			       "website-label", _("PackageKit Website"),
 			       "website", "www.packagekit.org",
 			       "comments", "PackageKit",
@@ -1273,9 +1275,17 @@ gpk_watch_menu_log_out_cb (GtkMenuItem *item, gpointer data)
  * gpk_watch_menu_restart_cb:
  **/
 static void
-gpk_watch_menu_restart_cb (GtkMenuItem *item, gpointer data)
+gpk_watch_menu_restart_cb (GtkMenuItem *item, GpkWatch *watch)
 {
-	gpk_restart_system ();
+	gboolean ret;
+	GError *error = NULL;
+
+	/* restart using ConsoleKit */
+	ret = egg_console_kit_restart (watch->priv->console, &error);
+	if (!ret) {
+		egg_warning ("restarting failed: %s", error->message);
+		g_error_free (error);
+	}
 }
 
 /**
@@ -1292,6 +1302,7 @@ gpk_watch_activate_status_cb (GtkStatusIcon *status_icon, GpkWatch *watch)
 	GtkWidget *image;
 	guint len;
 	gboolean show_hide = FALSE;
+	gboolean can_restart = FALSE;
 
 	g_return_if_fail (GPK_IS_WATCH (watch));
 
@@ -1327,8 +1338,10 @@ gpk_watch_activate_status_cb (GtkStatusIcon *status_icon, GpkWatch *watch)
 	}
 
 	/* restart computer */
-	if (watch->priv->restart == PK_RESTART_ENUM_SYSTEM ||
-	    watch->priv->restart == PK_RESTART_ENUM_SECURITY_SYSTEM) {
+	egg_console_kit_can_restart (watch->priv->console, &can_restart, NULL);
+	if (can_restart &&
+	    (watch->priv->restart == PK_RESTART_ENUM_SYSTEM ||
+	     watch->priv->restart == PK_RESTART_ENUM_SECURITY_SYSTEM)) {
 		/* TRANSLATORS: this menu item restarts the computer after an update */
 		widget = gtk_image_menu_item_new_with_mnemonic (_("_Restart computer"));
 		image = gtk_image_new_from_icon_name ("system-shutdown", GTK_ICON_SIZE_MENU);
@@ -1633,6 +1646,7 @@ gpk_watch_init (GpkWatch *watch)
 	watch->priv->notification_cached_messages = NULL;
 	watch->priv->restart = PK_RESTART_ENUM_NONE;
 	watch->priv->hide_warning = FALSE;
+	watch->priv->console = egg_console_kit_new ();
 
 	watch->priv->gconf_client = gconf_client_get_default ();
 
@@ -1742,6 +1756,7 @@ gpk_watch_finalize (GObject *object)
 	g_object_unref (watch->priv->gconf_client);
 	g_object_unref (watch->priv->client_primary);
 	g_object_unref (watch->priv->dialog);
+	g_object_unref (watch->priv->console);
 
 	G_OBJECT_CLASS (gpk_watch_parent_class)->finalize (object);
 }
